<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LinetypeMode</name>
    <message>
        <location filename="../LinetypeMode.js" line="+86"/>
        <source>Screen-based Line&amp;types</source>
        <translation>&amp;Zobrazení čar závislé na obrazovce</translation>
    </message>
</context>
</TS>
